[GRASS-SVN] r53133 - in grass/trunk/lib: cairodriver cluster datetime db/dbmi_base db/dbmi_client db/dbmi_driver display driver gis manage nviz raster raster3d rowio vector/Vlib vector/diglib vector/neta vector/vedit

svn_grass at osgeo.org svn_grass at osgeo.org
Sat Sep 8 12:34:59 PDT 2012


Author: neteler
Date: 2012-09-08 12:34:59 -0700 (Sat, 08 Sep 2012)
New Revision: 53133

Modified:
   grass/trunk/lib/cairodriver/Color.c
   grass/trunk/lib/cairodriver/Text.c
   grass/trunk/lib/cluster/c_distinct.c
   grass/trunk/lib/cluster/c_exec.c
   grass/trunk/lib/cluster/c_merge.c
   grass/trunk/lib/datetime/change.c
   grass/trunk/lib/datetime/incr3.c
   grass/trunk/lib/db/dbmi_base/cursor.c
   grass/trunk/lib/db/dbmi_base/dirent.c
   grass/trunk/lib/db/dbmi_base/index.c
   grass/trunk/lib/db/dbmi_client/c_desc_table.c
   grass/trunk/lib/db/dbmi_client/c_list_idx.c
   grass/trunk/lib/db/dbmi_client/c_listdb.c
   grass/trunk/lib/db/dbmi_client/copy_tab.c
   grass/trunk/lib/db/dbmi_client/delete_tab.c
   grass/trunk/lib/db/dbmi_driver/d_error.c
   grass/trunk/lib/db/dbmi_driver/d_execute.c
   grass/trunk/lib/display/cnversions.c
   grass/trunk/lib/display/draw2.c
   grass/trunk/lib/driver/init.c
   grass/trunk/lib/driver/parse_ftcap.c
   grass/trunk/lib/gis/debug.c
   grass/trunk/lib/gis/file_name.c
   grass/trunk/lib/gis/find_etc.c
   grass/trunk/lib/gis/find_file.c
   grass/trunk/lib/gis/get_window.c
   grass/trunk/lib/gis/gisinit.c
   grass/trunk/lib/gis/ilist.c
   grass/trunk/lib/gis/mapcase.c
   grass/trunk/lib/manage/list.c
   grass/trunk/lib/nviz/change_view.c
   grass/trunk/lib/nviz/cplanes_obj.c
   grass/trunk/lib/raster/cats.c
   grass/trunk/lib/raster/color_hist.c
   grass/trunk/lib/raster/color_rule.c
   grass/trunk/lib/raster/color_set.c
   grass/trunk/lib/raster/get_row.c
   grass/trunk/lib/raster/init.c
   grass/trunk/lib/raster/rasterlib.dox
   grass/trunk/lib/raster3d/defaults.c
   grass/trunk/lib/raster3d/error.c
   grass/trunk/lib/rowio/fileno.c
   grass/trunk/lib/vector/Vlib/build.c
   grass/trunk/lib/vector/Vlib/build_nat.c
   grass/trunk/lib/vector/Vlib/field.c
   grass/trunk/lib/vector/Vlib/geos.c
   grass/trunk/lib/vector/Vlib/level_two.c
   grass/trunk/lib/vector/Vlib/line.c
   grass/trunk/lib/vector/Vlib/list.c
   grass/trunk/lib/vector/Vlib/net.c
   grass/trunk/lib/vector/Vlib/overlay.c
   grass/trunk/lib/vector/diglib/plus.c
   grass/trunk/lib/vector/diglib/plus_area.c
   grass/trunk/lib/vector/diglib/plus_line.c
   grass/trunk/lib/vector/diglib/portable.c
   grass/trunk/lib/vector/diglib/spindex.c
   grass/trunk/lib/vector/diglib/struct_alloc.c
   grass/trunk/lib/vector/diglib/type.c
   grass/trunk/lib/vector/neta/centrality.c
   grass/trunk/lib/vector/neta/flow.c
   grass/trunk/lib/vector/vedit/cats.c
   grass/trunk/lib/vector/vedit/distance.c
Log:
doxygen errors fixed

Modified: grass/trunk/lib/cairodriver/Color.c
===================================================================
--- grass/trunk/lib/cairodriver/Color.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/cairodriver/Color.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -20,7 +20,9 @@
   This color will then be used for any subsequent drawing operation
   until a new source pattern is set.
   
-  \param color value
+  \param r red color value
+  \param g green color value
+  \param b blue color value
 */
 void Cairo_Color(int r, int g, int b)
 {

Modified: grass/trunk/lib/cairodriver/Text.c
===================================================================
--- grass/trunk/lib/cairodriver/Text.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/cairodriver/Text.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -317,7 +317,7 @@
   \brief Get list of fonts
 
   \param[out] list font list
-  \param[out] number of items in the list
+  \param[out] count number of items in the list
 */
 void Cairo_font_list(char ***list, int *count)
 {
@@ -331,7 +331,7 @@
   \brief Get fonts into
 
   \param[out] list font list
-  \param[out] number of items in the list
+  \param[out] count number of items in the list
 */
 void Cairo_font_info(char ***list, int *count)
 {

Modified: grass/trunk/lib/cluster/c_distinct.c
===================================================================
--- grass/trunk/lib/cluster/c_distinct.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/cluster/c_distinct.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -16,7 +16,7 @@
 /*!
   \brief Get distinct value
 
-  \param pointer to Cluster structure
+  \param C pointer to Cluster structure
   \param separation separation value
 
   \return distiction value

Modified: grass/trunk/lib/cluster/c_exec.c
===================================================================
--- grass/trunk/lib/cluster/c_exec.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/cluster/c_exec.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -15,10 +15,12 @@
 #include <grass/glocale.h>
 
 /*!
+  \param C pointer to Cluster structure
   \param maxclass maximum number of classes
   \param iterations maximum number of iterations
   \param convergence percentage of points stable
   \param separation minimum distance between class centroids
+  \param min_class_size minimum size of class
   \param checkpoint routine to be called at various steps
   \param interrupted boolean to check for interrupt
 

Modified: grass/trunk/lib/cluster/c_merge.c
===================================================================
--- grass/trunk/lib/cluster/c_merge.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/cluster/c_merge.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -16,7 +16,7 @@
 /*!
   \brief ?
   
-  \param pointer to Cluster structure
+  \param C pointer to Cluster structure
 
   \return 0
 */

Modified: grass/trunk/lib/datetime/change.c
===================================================================
--- grass/trunk/lib/datetime/change.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/datetime/change.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -45,8 +45,9 @@
  * elements are set to zero.
  </li></ul>
  *
- *
+ *  \param dt
  *  \param from
+ *  \param to
  *  \param round
  *  \return int
  */

Modified: grass/trunk/lib/datetime/incr3.c
===================================================================
--- grass/trunk/lib/datetime/incr3.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/datetime/incr3.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -30,6 +30,7 @@
  *from = src.from
  \endcode
  *
+ *  \param dt
  *  \param mode
  *  \param from
  *  \param to

Modified: grass/trunk/lib/db/dbmi_base/cursor.c
===================================================================
--- grass/trunk/lib/db/dbmi_base/cursor.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_base/cursor.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -30,7 +30,7 @@
    \brief Allocate table for cursor
 
    \param cursor pointer to dbCursor
-   \param ncol   number of column in table
+   \param ncols  number of column in table
 
    \return DB_OK on success
    \return error code on error

Modified: grass/trunk/lib/db/dbmi_base/dirent.c
===================================================================
--- grass/trunk/lib/db/dbmi_base/dirent.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_base/dirent.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -43,7 +43,7 @@
   Append one entry with name = NULL to mark end of array
   
   \param dirname directory name
-  \param[out] number of entities
+  \param[out] n number of entities
 
   \return pointer to dbDirent
   \return NULL on error

Modified: grass/trunk/lib/db/dbmi_base/index.c
===================================================================
--- grass/trunk/lib/db/dbmi_base/index.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_base/index.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -219,7 +219,7 @@
 /*!
   \brief Set index type to non-unique
   
-  \void return type void?
+  \todo return type void?
 
   \param index pointer to dbIndex
 

Modified: grass/trunk/lib/db/dbmi_client/c_desc_table.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/c_desc_table.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_client/c_desc_table.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -20,7 +20,7 @@
   
   \param driver db driver
   \param name table name
-  \param[out] pointer to dbTable structure
+  \param[out] table pointer to dbTable structure
 
   \return DB_OK on success
   \return DB_FAILED on failure

Modified: grass/trunk/lib/db/dbmi_client/c_list_idx.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/c_list_idx.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_client/c_list_idx.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -20,8 +20,8 @@
 
   \param driver db driver
   \param table_name table name
-  \param[out] list of db indexes
-  \param[out] number of items in the list
+  \param[out] list list of db indexes
+  \param[out] dbDriver number of items in the list
 
   \return DB_OK on success
   \return DB_FAILED on failure

Modified: grass/trunk/lib/db/dbmi_client/c_listdb.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/c_listdb.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_client/c_listdb.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -22,7 +22,7 @@
   \param path db path
   \param npaths number of given paths
   \param[out] handles handle infos
-  \param[out] number of handle infos
+  \param[out] count number of handle infos
 
   \return DB_OK on success
   \return DB_FAILED on failure

Modified: grass/trunk/lib/db/dbmi_client/copy_tab.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/copy_tab.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_client/copy_tab.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -409,12 +409,12 @@
 /*!
   \brief Copy a table
  
-  \param from_dvrname name of driver from table is copied
+  \param from_drvname name of driver from table is copied
   \param from_dbname name of database from table is copied
-  \param from_tbl_name name of table to be copied
-  \param to_dvrname name of driver to - where table is copied to
+  \param from_tblname name of table to be copied
+  \param to_drvname name of driver to - where table is copied to
   \param to_dbname name of database to - where table is copied to
-  \param to_dbname name of copied table
+  \param to_tblname name of copied table
 
   \return DB_OK on success
   \return DB_FAILED on failure
@@ -431,12 +431,12 @@
 /*!
   \brief Copy a table (by where statement)
 
-  \param from_dvrname name of driver from table is copied
+  \param from_drvname name of driver from table is copied
   \param from_dbname name of database from table is copied
-  \param from_tbl_name name of table to be copied
-  \param to_dvrname name of driver to - where table is copied to
+  \param from_tblname name of table to be copied
+  \param to_drvname name of driver to - where table is copied to
   \param to_dbname name of database to - where table is copied to
-  \param to_dbname name of copied table
+  \param to_tblname name of copied table
   \param where WHERE SQL condition (without where key word)
 
   \return DB_OK on success
@@ -455,12 +455,12 @@
 /*!
   \brief Copy a table (by select statement)
 
-  \param from_dvrname name of driver from table is copied
+  \param from_drvname name of driver from table is copied
   \param from_dbname name of database from table is copied
-  \param from_tbl_name name of table to be copied
-  \param to_dvrname name of driver to - where table is copied to
+  \param from_dbname name of table to be copied
+  \param to_drvname name of driver to - where table is copied to
   \param to_dbname name of database to - where table is copied to
-  \param to_dbname name of copied table
+  \param to_tblname name of copied table
   \param select full select statement
 
   \return DB_OK on success
@@ -479,12 +479,12 @@
 /*!
   \brief Copy a table (by keys)
 
-  \param from_dvrname name of driver from table is copied
+  \param from_drvname name of driver from table is copied
   \param from_dbname name of database from table is copied
-  \param from_tbl_name name of table to be copied
-  \param to_dvrname name of driver to - where table is copied to
+  \param from_tblname name of table to be copied
+  \param to_drvname name of driver to - where table is copied to
   \param to_dbname name of database to - where table is copied to
-  \param to_dbname name of copied table
+  \param to_tblname name of copied table
   \param selcol name of column used to select records by values in ivals or NULL
   \param ivals pointer to array of integer values or NULL
   \param nvals number of values in ivals

Modified: grass/trunk/lib/db/dbmi_client/delete_tab.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/delete_tab.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_client/delete_tab.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -19,7 +19,7 @@
 /*!
   \brief Delete table
 
-  \param drv driver name
+  \param drvname driver name
   \param dbname database name
   \param tblname table name
 

Modified: grass/trunk/lib/db/dbmi_driver/d_error.c
===================================================================
--- grass/trunk/lib/db/dbmi_driver/d_error.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_driver/d_error.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -60,7 +60,7 @@
 /*!
   \brief Append error message for DB driver
 
-  \param frmt formatted message
+  \param fmt formatted message
 */
 void db_d_append_error(const char *fmt, ...)
 {

Modified: grass/trunk/lib/db/dbmi_driver/d_execute.c
===================================================================
--- grass/trunk/lib/db/dbmi_driver/d_execute.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/db/dbmi_driver/d_execute.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -74,8 +74,6 @@
 /*!
   \brief Commit transaction
   
-  \param driver db driver
-  
   \return DB_OK on success
   \return DB_FAILED on failure
  */

Modified: grass/trunk/lib/display/cnversions.c
===================================================================
--- grass/trunk/lib/display/cnversions.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/display/cnversions.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -142,11 +142,11 @@
  * allows conversions between all three coordinate systems to be performed.
  * Note this routine is called by <i>D_setup</i>.
  *
- *  \param region
- *  \param top
- *  \param bottom
- *  \param left
- *  \param right
+ *  \param window region
+ *  \param t top
+ *  \param b bottom
+ *  \param l left
+ *  \param r right
  *  \return none
  */
 void D_do_conversions(const struct Cell_head *window,
@@ -217,10 +217,10 @@
  * D_get_src() returns the frame bounds in the source coordinate system
  * (used by D_* functions)
  *
- *  \param top
- *  \param bottom
- *  \param left
- *  \param right
+ *  \param t top
+ *  \param b bottom
+ *  \param l left
+ *  \param r right
  *  \return void
  */
 void D_get_src(double *t, double *b, double *l, double *r)
@@ -265,10 +265,10 @@
  * The various D_setup() commands all set the destination coordinate
  * system to the current frame reported by R_get_window().
  *
- *  \param top
- *  \param bottom
- *  \param left
- *  \param right
+ *  \param t top
+ *  \param b bottom
+ *  \param l left
+ *  \param r right
  *  \return none
  */
 void D_get_dst(double *t, double *b, double *l, double *r)
@@ -309,7 +309,7 @@
  * Returns a <i>row</i> value in the array coordinate system when provided the
  * corresponding <b>y</b> value in the screen coordinate system.
  *
- *  \param y
+ *  \param D_row y
  *  \return double
  */
 
@@ -325,7 +325,7 @@
  * Returns a <i>column</i> value in the array coordinate system when provided the
  * corresponding <b>x</b> value in the screen coordinate system.
  *
- *  \param x
+ *  \param D_col x
  *  \return double
  */
 
@@ -341,7 +341,7 @@
  * Returns a <i>north</i> value in the earth coordinate system when provided the
  * corresponding <b>y</b> value in the screen coordinate system.
  *
- *  \param y
+ *  \param D_row y
  *  \return double
  */
 
@@ -357,7 +357,7 @@
  * Returns an <i>east</i> value in the earth coordinate system when provided the
  * corresponding <b>x</b> value in the screen coordinate system.
  *
- *  \param x
+ *  \param D_col x
  *  \return double
  */
 
@@ -373,7 +373,7 @@
  * Returns a <i>y</i> value in the earth coordinate system when provided the
  * corresponding <b>row</b> value in the array coordinate system.
  *
- *  \param row
+ *  \param A_row row
  *  \return double
  */
 
@@ -390,7 +390,7 @@
  * provided the corresponding <b>column</b> value in the array coordinate
  * system.
  *
- *  \param column
+ *  \param A_col column
  *  \return double
  */
 
@@ -406,7 +406,7 @@
  * Returns a <i>y</i> value in the screen coordinate system when provided the
  * corresponding <b>row</b> value in the array coordinate system.
  *
- *  \param row
+ *  \param A_row row
  *  \return double
  */
 
@@ -423,7 +423,7 @@
  * provided the corresponding <b>column</b> value in the array coordinate
  * system.
  *
- *  \param column
+ *  \param A_col column
  *  \return double
  */
 
@@ -439,7 +439,7 @@
  * Returns a <i>y</i> value in the screen coordinate system when provided the
  * corresponding <b>north</b> value in the earth coordinate system.
  *
- *  \param north
+ *  \param U_row north
  *  \return double
  */
 
@@ -455,7 +455,7 @@
  * Returns an <i>x</i> value in the screen coordinate system when provided the
  * corresponding <b>east</b> value in the earth coordinate system.
  *
- *  \param east
+ *  \param U_col east
  *  \return double
  */
 
@@ -471,7 +471,7 @@
  * Returns a <i>row</i> value in the array coordinate system when provided the
  * corresponding <b>north</b> value in the earth coordinate system.
  *
- *  \param north
+ *  \param U_row north
  *  \return double
  */
 
@@ -487,7 +487,7 @@
  * Returns a <i>column</i> value in the array coordinate system when provided the
  * corresponding <b>east</b> value in the earth coordinate system.
  *
- *  \param east
+ *  \param U_col east
  *  \return double
  */
 

Modified: grass/trunk/lib/display/draw2.c
===================================================================
--- grass/trunk/lib/display/draw2.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/display/draw2.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -143,10 +143,10 @@
  * Sets the clipping window to the pixel window that corresponds
  * to the current database region. This is the default.
  *
- *  \param top
- *  \param bottom
- *  \param left
- *  \param right
+ *  \param t top
+ *  \param b bottom
+ *  \param l left
+ *  \param r right
  */
 
 void D_set_clip(double t, double b, double l, double r)

Modified: grass/trunk/lib/driver/init.c
===================================================================
--- grass/trunk/lib/driver/init.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/driver/init.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -42,7 +42,7 @@
 /*!
   \brief Initialize display driver
 
-  \param pointer to driver structure
+  \param drv pointer to driver structure
 */
 void LIB_init(const struct driver *drv)
 {

Modified: grass/trunk/lib/driver/parse_ftcap.c
===================================================================
--- grass/trunk/lib/driver/parse_ftcap.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/driver/parse_ftcap.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -119,7 +119,7 @@
 /*!
   \brief Free allocated GFONT_CAP structure
 
-  \param fpcap pointer to GFONT_CAP to be freed
+  \param ftcap pointer to GFONT_CAP to be freed
 */
 void free_fontcap(struct GFONT_CAP *ftcap)
 {

Modified: grass/trunk/lib/gis/debug.c
===================================================================
--- grass/trunk/lib/gis/debug.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/debug.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -1,17 +1,14 @@
-
 /**
  * \file debug.c
  *
  * \brief GIS Library - Debug functions.
  *
- * (C) 2001-2008 by the GRASS Development Team
+ * (C) 2001-2012 by the GRASS Development Team
  *
  * This program is free software under the GNU General Public License
  * (>=v2). Read the file COPYING that comes with GRASS for details.
  *
  * \author GRASS GIS Development Team
- *
- * \date 1999-2008
  */
 
 #include <stdio.h>
@@ -25,6 +22,26 @@
 static int grass_debug_level;
 
 /**
+ * \brief Initiate debugging.
+ */
+void G_init_debug(void)
+{
+    const char *lstr;
+
+    if (G_is_initialized(&initialized))
+	return;
+
+    lstr = G__getenv("DEBUG");
+
+    if (lstr != NULL)
+	grass_debug_level = atoi(lstr);
+    else
+	grass_debug_level = 0;
+
+    G_initialize_done(&initialized);
+}
+
+/**
  * \brief Print debugging message.
  *
  * Print debugging message if environment variable GRASS_DEBUG_LEVEL
@@ -45,24 +62,6 @@
  * \return 0 on error
  * \return 1 on success
  */
-
-void G_init_debug(void)
-{
-    const char *lstr;
-
-    if (G_is_initialized(&initialized))
-	return;
-
-    lstr = G__getenv("DEBUG");
-
-    if (lstr != NULL)
-	grass_debug_level = atoi(lstr);
-    else
-	grass_debug_level = 0;
-
-    G_initialize_done(&initialized);
-}
-
 int G_debug(int level, const char *msg, ...)
 {
     char *filen;

Modified: grass/trunk/lib/gis/file_name.c
===================================================================
--- grass/trunk/lib/gis/file_name.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/file_name.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -19,7 +19,7 @@
 /*!
   \brief Builds full path names to GIS data files
 
-  If name is of the form nnn at ppp then path is set
+  If name is of the form "nnn at ppp" then path is set
   as if name had been nnn and mapset had been ppp
   (mapset parameter itself is ignored in this case)
   

Modified: grass/trunk/lib/gis/find_etc.c
===================================================================
--- grass/trunk/lib/gis/find_etc.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/find_etc.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -55,9 +55,9 @@
  *  note:
  *      rejects all names that begin with "."
  *
- *  \param char *name       file name to look for
+ *  \param name file name to look for
  *
- *  \return char *  pointer to a string with full path to
+ *  \return pointer to a string with full path to
  *              where file was found, or NULL if not found
  */
 char *G_find_etc(const char *name)

Modified: grass/trunk/lib/gis/find_file.c
===================================================================
--- grass/trunk/lib/gis/find_file.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/find_file.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -143,9 +143,9 @@
  *
  * Returns the mapset name where the file was found.
  *
- * If the user specifies a fully qualified element (<i>name at mapset</i>)
- * which exists, then G_find_file() modifies <i>name</i>
- * by removing the "@<i>mapset</i>" part.
+ * If the user specifies a fully qualified element (name at mapset)
+ * which exists, then G_find_file() modifies "name"
+ * by removing the "@mapset" part.
  *
  * Rejects all names that begin with "."
  *

Modified: grass/trunk/lib/gis/get_window.c
===================================================================
--- grass/trunk/lib/gis/get_window.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/get_window.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -99,7 +99,7 @@
   
   G_fatal_error() is called on error
   
-  \param window[out] pointer to Cell_head
+  \param window pointer to Cell_head
   \param element element type
   \param name map name
   \param mapset mapset name

Modified: grass/trunk/lib/gis/gisinit.c
===================================================================
--- grass/trunk/lib/gis/gisinit.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/gisinit.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -32,6 +32,7 @@
 /*!
   \brief Initialize GIS Library and ensures a valid mapset is available.
   
+  \param version
   \param pgm program (module) name
   
   \return always returns 0 on success

Modified: grass/trunk/lib/gis/ilist.c
===================================================================
--- grass/trunk/lib/gis/ilist.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/ilist.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -38,7 +38,7 @@
  *  In case reallocation fails, G_fatal_error() will be invoked by the
  *  allocation function.
  *
- * \param ilist The ilist pointer
+ * \param list The ilist pointer
  * \param val The value to attach
  *
  * */

Modified: grass/trunk/lib/gis/mapcase.c
===================================================================
--- grass/trunk/lib/gis/mapcase.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/gis/mapcase.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -12,8 +12,8 @@
  * letters in the string <b>s</b> are converted to their lower case equivalent.
  * Returns <b>s.</b>
  *
- *  \param s
- *  \return char * 
+ *  \param string
+ *  \return char
  */
 
 char *G_tolcase(char *string)
@@ -42,8 +42,8 @@
  * Lower case letters in the string <b>s</b> are converted to their upper case equivalent.
  * Returns <b>s.</b>
  *
- *  \param s
- *  \return char * 
+ *  \param string
+ *  \return char
  */
 
 char *G_toucase(char *string)

Modified: grass/trunk/lib/manage/list.c
===================================================================
--- grass/trunk/lib/manage/list.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/manage/list.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -18,7 +18,7 @@
 /*!
   \brief Get list structure
 
-  \param element id
+  \param n element id
   
   \return pointer to list structure
   \return NULL on error

Modified: grass/trunk/lib/nviz/change_view.c
===================================================================
--- grass/trunk/lib/nviz/change_view.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/nviz/change_view.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -88,8 +88,8 @@
 /*!
    \brief Change position of view
 
-   \param data nviz data
-   \param x_pos,y_pos x,y position (model coordinates)
+   \param x_pos x position (model coordinates)
+   \param y_pos y position (model coordinates)
 
    \return 1
  */
@@ -149,7 +149,6 @@
 /*!
    \brief Change viewpoint height
 
-   \param data nviz data
    \param height height value (world coordinates)
 
    \return 1
@@ -191,7 +190,6 @@
 /*!
    \brief Change viewpoint perspective (field of view)
 
-   \param data nviz data
    \param persp perspective value (0-100, in degrees)
 
    \return 1
@@ -213,8 +211,7 @@
 /*!
    \brief Change viewpoint twist
 
-   \param data nviz data
-   \param persp twist value (-180-180, in degrees)
+   \param twist persp twist value (-180-180, in degrees)
 
    \return 1
  */
@@ -314,6 +311,7 @@
   Changes viewpoint and viewdir.
   Based on visualization/nviz/src/togl_flythrough.c and simplified.
 
+  \param data nviz data
   \param fly_info values computed from mouse movement
   \param scale rate of movement
   \param lateral type of movement

Modified: grass/trunk/lib/nviz/cplanes_obj.c
===================================================================
--- grass/trunk/lib/nviz/cplanes_obj.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/nviz/cplanes_obj.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -23,6 +23,9 @@
    The number of clip planes is fixed (MAX_CPLANES) and
    we'll create them all ahead of time anyway we just let
    the user decide on the id for each.
+
+   \param data nviz data
+   \param id
  */
 int Nviz_new_cplane(nv_data * data, int id)
 {
@@ -68,6 +71,7 @@
 /*!
    \brief Draw the clip plane
 
+   \param data nviz data
    \param bound1
    \param bound2
  */

Modified: grass/trunk/lib/raster/cats.c
===================================================================
--- grass/trunk/lib/raster/cats.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/cats.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -96,7 +96,7 @@
  *
  * \param name raster map name
  * \param mapset mapset name
- * \param[out] cats pointer to Cats structure
+ * \param[out] pcats pointer to Cats structure
  * 
  * \return -1 on error
  * \return 0 on success
@@ -132,7 +132,7 @@
  *
  * \param name vector map name
  * \param mapset mapset name
- * \param[out] cats pointer to Cats structure
+ * \param[out] pcats pointer to Cats structure
  * 
  * \return -1 on error
  * \return 0 on success
@@ -285,7 +285,7 @@
  * map layer does not have a title, then a pointer to the empty string
  * "" is returned.
  *
- * \param cats pointer to Categories structure
+ * \param pcats pointer to Categories structure
  *
  * \return title
  * \return "" if missing
@@ -546,6 +546,7 @@
  * \param rast_row raster row to update stats
  * \param ncols number of columns
  * \param pcats pointer to Categories structure
+ * \param data_type map type
  *
  * \return -1 on error
  * \return 1 on success
@@ -1174,8 +1175,10 @@
    \brief Set category fmt (?)
 
    \param fmt
-   \param m1,
-   \param a1,m2,a2
+   \param m1
+   \param a1
+   \param m2
+   \param a2
    \param pcats pointer to Categories structure
  */
 void Rast_set_cats_fmt(const char *fmt, double m1, double a1, double m2,

Modified: grass/trunk/lib/raster/color_hist.c
===================================================================
--- grass/trunk/lib/raster/color_rule.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/color_rule.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -26,9 +26,9 @@
   
   See Rast_add_color_rule() for details.
   
-  \param v1 cell value
+  \param val1 cell value
   \param r1,g1,b1 color value
-  \param v2 cell value
+  \param val2 cell value
   \param r2,g2,b2 color value
   \param[in,out] colors pointer to color table structure
 */
@@ -46,9 +46,9 @@
   
   See Rast_add_color_rule() for details.
   
-  \param v1 cell value
+  \param cat1 cell value
   \param r1,g1,b1 color value
-  \param v2 cell value
+  \param cat2 cell value
   \param r2,g2,b2 color value
   \param[in,out] colors pointer to color table structure
 */
@@ -66,9 +66,9 @@
   
   See Rast_add_color_rule() for details.
   
-  \param v1 cell value
+  \param cat1 cell value
   \param r1,g1,b1 color value
-  \param v2 cell value
+  \param cat2 cell value
   \param r2,g2,b2 color value
   \param[in,out] colors pointer to color table structure
 */
@@ -94,9 +94,9 @@
    - If <em>map_type</em> is FCELL_TYPE, calls Rast_add_f_color_rule()
    - If <em>map_type</em> is DCELL_TYPE, calls Rast_add_d_color_rule()
    
-  \param v1 cell value
+  \param val1 cell value
   \param r1,g1,b1 color value
-  \param v2 cell value
+  \param val2 cell value
   \param r2,g2,b2 color value
   \param[in,out] colors pointer to color table structure
   \param data_type raster data type (CELL, FCELL, DCELL)

Modified: grass/trunk/lib/raster/color_set.c
===================================================================
--- grass/trunk/lib/raster/color_set.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/color_set.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -51,7 +51,7 @@
  * 
  * See Rast_set_c_color() for detailed information.
  *
- * \param cat raster cell value
+ * \param val raster cell value
  * \param r red value
  * \param g green value
  * \param b blue value

Modified: grass/trunk/lib/raster/get_row.c
===================================================================
--- grass/trunk/lib/raster/get_row.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/get_row.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -651,7 +651,6 @@
  * \param fd file descriptor for the opened raster map
  * \param buf buffer for the row to be placed into
  * \param row data row desired
- * \param data_type data type
  *
  * \return void
  */
@@ -668,7 +667,6 @@
  * \param fd file descriptor for the opened raster map
  * \param buf buffer for the row to be placed into
  * \param row data row desired
- * \param data_type data type
  *
  * \return void
  */
@@ -685,7 +683,6 @@
  * \param fd file descriptor for the opened raster map
  * \param buf buffer for the row to be placed into
  * \param row data row desired
- * \param data_type data type
  *
  * \return void
  */
@@ -991,6 +988,7 @@
 
    \param fd file descriptor for the opened map
    \param buf buffer for the row to be placed into
+   \param flags
    \param row data row desired
 
    \return void

Modified: grass/trunk/lib/raster/init.c
===================================================================
--- grass/trunk/lib/raster/init.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/init.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -37,7 +37,6 @@
  *
  * Initializes GIS engine and ensures a valid mapset is available.
  *
- * \param[in] pgm Program (module) name
  * \return always returns 0 on success
  * \return exit() is called on error
  */

Modified: grass/trunk/lib/raster/rasterlib.dox
===================================================================
--- grass/trunk/lib/raster/rasterlib.dox	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/rasterlib.dox	2012-09-08 19:34:59 UTC (rev 53133)
@@ -783,7 +783,7 @@
 
 \section  GRASS_5_raster_API GRASS 5 raster API
 
-<em>Needs to be merged into above sections.<em>
+<em>Needs to be merged into above sections.</em>
 
 \subsection The_CELL_Data_Type The CELL Data Type
 

Modified: grass/trunk/lib/raster3d/defaults.c
===================================================================
--- grass/trunk/lib/raster3d/defaults.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster3d/defaults.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -69,7 +69,7 @@
 
 
 /*!
- * \brief 
+ * \brief set compression mode
  *
  * <em>doCompress</em> should be one of RASTER3D_NO_COMPRESSION and
  * RASTER3D_COMPRESSION, <em>doRle</em> should be either RASTER3D_NO_RLE or
@@ -112,10 +112,8 @@
 
 
 /*!
- * \brief 
+ * \brief get compression mode
  *
- * 
- *
  *  \param doCompress
  *  \param doLzw
  *  \param doRle
@@ -141,10 +139,8 @@
 
 
 /*!
- * \brief 
+ * \brief set cache size
  *
- *  set cache size
- *
  *  \param nTiles
  *  \return void
  */
@@ -161,10 +157,8 @@
 
 
 /*!
- * \brief 
+ * \brief get cache size
  *
- *  get cache size
- *
  *  \return int
  */
 
@@ -179,8 +173,6 @@
 /*!
  * \brief Set cache limit
  *
- *  set cache limit
- *
  *  \param nBytes
  *  \return void
  */
@@ -199,9 +191,6 @@
 /*!
  * \brief Get cache limit
  *
- *  get cache limit
- *
- *  \param nBytes
  *  \return int
  */
 
@@ -214,10 +203,8 @@
 
 
 /*!
- * \brief 
+ * \brief set G3d file type
  *
- *  set G3d file type
- *
  *  \param type
  *  \return void
  */
@@ -234,11 +221,8 @@
 
 
 /*!
- * \brief 
+ * \brief get G3d file type
  *
- * get G3d file type
- *
- *  \param type
  *  \return int
  */
 
@@ -251,10 +235,8 @@
 
 
 /*!
- * \brief 
+ * \brief set Tile Dimension
  *
- * set Tile Dimension
- *
  *  \param tileX
  *  \param tileY
  *  \param tileZ
@@ -280,10 +262,8 @@
 
 
 /*!
- * \brief 
+ * \brief get Tile Dimension
  *
- *  get Tile Dimension
- *
  *  \param tileX
  *  \param tileY
  *  \param tileZ
@@ -301,11 +281,9 @@
 
 
 /*!
- * \brief 
+ * \brief set error function
  *
- *  set error function
- *
- *  \param 
+ *  \param fun
  *  \return void
  */
 
@@ -318,9 +296,7 @@
 
 
 /*!
- * \brief 
- *
- * Initializes the default values described
+ * \brief Initializes the default values described
  * in RASTER3D Defaults.  Applications have to use this function only if they need to
  * query the default values before the first file (either old or new) has been
  * opened.

Modified: grass/trunk/lib/raster3d/error.c
===================================================================
--- grass/trunk/lib/raster3d/error.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster3d/error.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -14,11 +14,9 @@
 
 
 /*!
- * \brief 
+ * \brief This function ignores the error.
  *
- *  This function ignores the error.
- *
- *  \param 
+ *  \param msg
  *  \return void
  */
 
@@ -28,12 +26,12 @@
 
 
 /*!
- * \brief 
+ * \brief Prints error message
  *
  *  This function prints the
- * error message <em>msg</em> to <em>stderr</em> and returns.
+ *  error message <em>msg</em> to <em>stderr</em> and returns.
  *
- *  \param 
+ *  \param msg
  *  \return void
  */
 
@@ -46,12 +44,12 @@
 
 
 /*!
- * \brief 
+ * \brief Prints fatal error message
  *
- *  This function prints the
- * error message <em>msg</em>, and terminates the program with an error status.
+ *  This function prints the fatal
+ *  error message <em>msg</em>, and terminates the program with an error status.
  *
- *  \param 
+ *  \param msg
  *  \return void
  */
 

Modified: grass/trunk/lib/rowio/fileno.c
===================================================================
--- grass/trunk/lib/rowio/fileno.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/rowio/fileno.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -18,7 +18,7 @@
  *
  * Returns the file descriptor associated with the ROWIO structure.
  *
- * \param r pointer to ROWIO structure
+ * \param R pointer to ROWIO structure
  *
  * \return file descriptor
  */

Modified: grass/trunk/lib/vector/Vlib/build.c
===================================================================
--- grass/trunk/lib/vector/Vlib/build.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/build.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -171,7 +171,7 @@
 /*!
    \brief Find area outside island
 
-   \param Map_info vector map
+   \param Map vector map
    \param isle isle id
 
    \return area id
@@ -368,7 +368,7 @@
 /*!
    \brief (Re)Attach isle to area
 
-   \param Map_info vector map
+   \param Map vector map
    \param isle isle id
 
    \return 0
@@ -405,7 +405,7 @@
 /*!
    \brief (Re)Attach isles to areas in given bounding box
 
-   \param Map_info vector map
+   \param Map vector map
    \param box bounding box
 
    \return 0
@@ -469,7 +469,7 @@
     This problem can be avoided altogether if properly attached
     centroids are skipped MM 2009
 
-   \param Map_info vector map
+   \param Map vector map
    \param box bounding box
 
    \return 0
@@ -742,6 +742,7 @@
   implementation issues.
 
   \param Map pointer to Map_info
+  \param build
 */
 void Vect__build_downgrade(struct Map_info *Map, int build)
 {

Modified: grass/trunk/lib/vector/Vlib/build_nat.c
===================================================================
--- grass/trunk/lib/vector/Vlib/build_nat.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/build_nat.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -24,7 +24,7 @@
 /*!
    \brief Build topology 
 
-   \param Map_info vector map
+   \param Map vector map
    \param build build level
 
    \return 1 on success

Modified: grass/trunk/lib/vector/Vlib/field.c
===================================================================
--- grass/trunk/lib/vector/Vlib/field.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/field.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -205,6 +205,7 @@
 
   \param p pointer to existing dblinks structure
   \param field layer number
+  \param name layer name
 
   \return 1 dblink for field exists
   \return 0 dblink does not exist for field

Modified: grass/trunk/lib/vector/Vlib/geos.c
===================================================================
--- grass/trunk/lib/vector/Vlib/geos.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/geos.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -119,6 +119,7 @@
    You should free allocated memory by GEOSGeom_destroy().
 
    \param Map pointer to Map_info structure
+   \param points pointer to line_pnts structure
    \param type feature type (see supported types)
 
    \return pointer to GEOSGeometry instance

Modified: grass/trunk/lib/vector/Vlib/level_two.c
===================================================================
--- grass/trunk/lib/vector/Vlib/level_two.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/level_two.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -39,7 +39,7 @@
 /*!
    \brief Get number of primitives in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
    \param type feature type
 
    \return number of primitives
@@ -67,7 +67,7 @@
 /*!
    \brief Fetch number of features (points, lines, boundaries, centroids) in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of features
  */
@@ -79,7 +79,7 @@
 /*!
    \brief Get number of areas in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of areas
  */
@@ -91,7 +91,7 @@
 /*!
    \brief Fetch number of kernels in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of kernels
  */
@@ -104,7 +104,7 @@
 /*!
    \brief Get number of faces in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of faces
  */
@@ -117,7 +117,7 @@
 /*!
    \brief Fetch number of volumes in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of volumes
  */
@@ -130,7 +130,7 @@
 /*!
    \brief Get number of islands in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of islands
  */
@@ -143,7 +143,7 @@
 /*!
    \brief Fetch number of holes in vector map
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of holes
  */
@@ -156,7 +156,7 @@
 /*!
    \brief Get number of defined dblinks
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of dblinks
  */
@@ -172,7 +172,7 @@
    Note: Vect_set_updated() must be called to maintain list of updated
    features
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of updated features
  */
@@ -187,7 +187,7 @@
    Note: Vect_set_updated() must be called to maintain list of updated
    features
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
    \param idx index
 
    \return updated line
@@ -203,7 +203,7 @@
    Note: Vect_set_updated() must be called to maintain list of updated
    features
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
    \param idx index
 
    \return updated line
@@ -216,7 +216,7 @@
 /*!
    \brief Get number of updated nodes
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
 
    \return number of updated nodes
  */
@@ -231,7 +231,7 @@
    Note: Vect_set_updated() must be called to maintain list of updated
    features
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
    \param idx index
 
    \return updated node
@@ -244,7 +244,7 @@
 /*!
    \brief Get line type
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
    \param line line id
 
    \return line type
@@ -262,7 +262,7 @@
 /*!
    \brief Get node coordinates
 
-   \param map pointer to Map_info struct
+   \param Map pointer to Map_info struct
    \param num node id
    \param x,y,z coordinates values (for 2D coordinates z is NULL)
 

Modified: grass/trunk/lib/vector/Vlib/line.c
===================================================================
--- grass/trunk/lib/vector/Vlib/line.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/line.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -91,7 +91,7 @@
 
    \param Points pointer to line_ptns structure
    \param x,y,z  array of coordinates
-   \param number of points to be copied
+   \param n number of points to be copied
 
    \return 0 on success
    \return -1 on out of memory

Modified: grass/trunk/lib/vector/Vlib/list.c
===================================================================
--- grass/trunk/lib/vector/Vlib/list.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/list.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -279,7 +279,8 @@
  * \brief Append new item to the end of list if not yet present 
  *
  * \param[in,out] list pointer to ilist structure
- * \param val new item to append to the end of list
+ * \param id new item to append to the end of list
+ * \param box bounding box
  *
  * \return 0 on success
  * \return 1 on error
@@ -352,7 +353,7 @@
  * \brief Remove a given value (item) from list
  *
  * \param[in,out] list pointer to boxlist structure
- * \param val to remove
+ * \param id to remove
  *
  * \return 0 on success
  * \return 1 on error
@@ -406,7 +407,7 @@
  * \brief Find a given item in the list
  *
  * \param list pointer to boxlist structure
- * \param val value of item
+ * \param id value of item
  *
  * \return 1 if an item is found
  * \return 0 no found item in the list

Modified: grass/trunk/lib/vector/Vlib/net.c
===================================================================
--- grass/trunk/lib/vector/Vlib/net.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/net.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -552,6 +552,7 @@
    \param Map vector map
    \param line line id
    \param direction direction (GV_FORWARD, GV_BACKWARD) 
+   \param[out] cost
 
    \return 1 OK
    \return 0 does not exist (was not inserted)
@@ -638,6 +639,7 @@
    \param[out] Points1 pointer to structure where to store vertices on nearest line to node1 (or NULL)
    \param[out] Points2 pointer to structure where to store vertices on nearest line to node2 (or NULL)
    \param[out] pointer where to distance to the line (or NULL)
+   \param[out] distance
 
    \return number of nodes found (0,1,2)
  */
@@ -884,7 +886,7 @@
    \param costs pointer where to store costs on the network (or NULL)
    \param Points pointer to the structure where to store vertices of shortest path (or NULL)
    \param List pointer to the structure where list of lines on the network is stored (or NULL)
-   \param List pointer to the structure where list of nodes on the network is stored (or NULL)
+   \param NodesList pointer to the structure where list of nodes on the network is stored (or NULL)
    \param FPoints pointer to the structure where to store line from 'from' to first network node (or NULL)
    \param TPoints pointer to the structure where to store line from last network node to 'to' (or NULL)
    \param fdist distance from 'from' to the net (or NULL)

Modified: grass/trunk/lib/vector/Vlib/overlay.c
===================================================================
--- grass/trunk/lib/vector/Vlib/overlay.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/Vlib/overlay.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -47,9 +47,11 @@
    \brief Overlay 2 vector maps and create new one
 
    \param AMap vector map A
+   \param atype feature type for A
    \param AList unused ?
    \param AAList unused ?
    \param BMap vector map B
+   \param btype feature type for B
    \param BList unused ?
    \param BAList unused ?
    \param operator operator code
@@ -89,7 +91,6 @@
    \param btype feature type for B
    \param BList unused ?
    \param BAList unused ?
-   \param operator operator code
    \param OMap output vector map
 
    \return 1 on success

Modified: grass/trunk/lib/vector/diglib/plus.c
===================================================================
--- grass/trunk/lib/vector/diglib/plus.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/plus.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -366,7 +366,7 @@
 /*!
  * \brief Writes topo structure (nodes) to topo file
  *
- * \param[in,out] fp_plus topo file
+ * \param[in,out] plus topo file
  * \param[in] Plus pointer to Plus_head structure
  *
  * \return 0 on success
@@ -390,7 +390,7 @@
 /*!
  * \brief Writes topo structure (lines) to topo file
  *
- * \param[in,out] fp_plus topo file
+ * \param[in,out] plus topo file
  * \param[in] Plus pointer to Plus_head structure
  *
  * \return 0 on success
@@ -415,7 +415,7 @@
 /*!
  * \brief Writes topo structure (areas) to topo file
  *
- * \param[in,out] fp_plus topo file
+ * \param[in,out] plus topo file
  * \param[in] Plus pointer to Plus_head structure
  *
  * \return 0 on success
@@ -440,7 +440,7 @@
 /*!
  * \brief Writes topo structure (isles) to topo file
  *
- * \param[in,out] fp_plus topo file
+ * \param[in,out] plus topo file
  * \param[in] Plus pointer to Plus_head structure
  *
  * \return 0 on success

Modified: grass/trunk/lib/vector/diglib/plus_area.c
===================================================================
--- grass/trunk/lib/vector/diglib/plus_area.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/plus_area.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -173,6 +173,7 @@
  * \param[in] plus pointer to Plus_head structure
  * \param[in] n_lines number of lines
  * \param[in] lines array of lines, negative for reverse direction
+ * \param[in] box bounding box
  *
  * \return number of new area
  * \return -1 on error
@@ -459,6 +460,7 @@
  * \param[in] current_line current line id, negative if request for node 2
  * \param[in] side side GV_RIGHT or GV_LEFT
  * \param[in] type line type (GV_LINE, GV_BOUNDARY or both)
+ * \param[in] angle
  *
  * \return line number of next angle to follow an line (negative if connected by node2)
  *               (number of current line may be return if dangle - this is used in build)
@@ -671,6 +673,7 @@
  * \param[in] plus pointer to Plus_head structure
  * \param[in] n_lines number of lines
  * \param[in] lines array of lines, negative for reverse direction 
+ * \param[in] box bounding box
  *
  * \return number of new isle
  * \return -1 on error

Modified: grass/trunk/lib/vector/diglib/plus_line.c
===================================================================
--- grass/trunk/lib/vector/diglib/plus_line.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/plus_line.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -120,6 +120,7 @@
  * \param[in] type feature type
  * \param[in] Points line geometry
  * \param[in] offset line offset
+ * \param[in] box bounding box
  *
  * \return -1 on error      
  * \return line id
@@ -175,6 +176,7 @@
  * \param[in] type feature type
  * \param[in] Points line geometry
  * \param[in] offset line offset
+ * \param[in] box bounding box
  *
  * \return -1 on error      
  * \return line id
@@ -201,6 +203,7 @@
  *
  * \param[in,out] plus pointer to Plus_head structure
  * \param[in] line line id
+ * \param[in] x,y,z coordinates
  *
  * \return -1 on error
  * \return  0 OK

Modified: grass/trunk/lib/vector/diglib/portable.c
===================================================================
--- grass/trunk/lib/vector/diglib/portable.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/portable.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -636,6 +636,7 @@
    \param buf data buffer
    \param cnt number of members
    \param[in,out] fp pointer to struct gvfile
+   \param port_off_t_size
 
    \return 0 error
    \return 1 OK

Modified: grass/trunk/lib/vector/diglib/spindex.c
===================================================================
--- grass/trunk/lib/vector/diglib/spindex.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/spindex.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -430,6 +430,7 @@
 
    \param Plus pointer to Plus_head structure
    \param line line id
+   \param x,y,z coordinates
 
    \return 0
  */

Modified: grass/trunk/lib/vector/diglib/struct_alloc.c
===================================================================
--- grass/trunk/lib/vector/diglib/struct_alloc.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/struct_alloc.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -43,7 +43,7 @@
 /*!
   \brief Free node structure
 
-  \param pointer to P_node struct to be freed
+  \param Node pointer to P_node struct to be freed
 */
 void dig_free_node(struct P_node *Node)
 {
@@ -181,10 +181,11 @@
 /*!
   \brief Reallocate array of pointers to lines.
   
- \param add space for 'add' number of lines is added.
+  \param Plus pointer to Plus_head structure
+  \param add space for 'add' number of lines is added.
  
- \return 0 on success
- \return -1 on error
+  \return 0 on success
+  \return -1 on error
 */
 int dig_alloc_lines(struct Plus_head *Plus, int add)
 {
@@ -205,6 +206,7 @@
 /*!
   \brief Reallocate array of pointers to areas.
 
+  \param Plus pointer to Plus_head structure
   \param add space for 'add' number of areas is added
  
   \return 0 on success
@@ -229,6 +231,7 @@
 /*!
   \brief Reallocate array of pointers to isles
 
+  \param Plus pointer to Plus_head structure
   \param add space for 'add' number of isles is added.
  
   \return 0 on success
@@ -273,7 +276,7 @@
 /*!
   \brief Free area structure
 
-  \param pointer to P_area struct to be freed
+  \param Area pointer to P_area struct to be freed
 */
 void dig_free_area(struct P_area *Area)
 {
@@ -308,7 +311,7 @@
 /*!
   \brief Free isle structure
 
-  \param pointer to P_isle struct to be freed
+  \param Isle pointer to P_isle struct to be freed
 */
 void dig_free_isle(struct P_isle *Isle)
 {
@@ -368,7 +371,7 @@
   \brief Allocate room for 'num' fields and category arrays 
   in struct line_cats 
 
-  \param points pointer to line_cats struct
+  \param cats pointer to line_cats struct
   \param num number of cats
  
   \return 0 on success
@@ -456,7 +459,7 @@
 /*!
   \brief Allocate space in  P_isle for add new lines
 
-  \param area pointer to P_area struct
+  \param isle pointer to P_area struct
   \param add number of isle to be added
 
   \return 0 on success

Modified: grass/trunk/lib/vector/diglib/type.c
===================================================================
--- grass/trunk/lib/vector/diglib/type.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/diglib/type.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -50,7 +50,7 @@
 /*!
    \brief Convert type from store type
 
-   \param type feature store type
+   \param stype feature store type
 
    \return type
  */

Modified: grass/trunk/lib/vector/neta/centrality.c
===================================================================
--- grass/trunk/lib/vector/neta/centrality.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/neta/centrality.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -27,7 +27,7 @@
    Array degree has to be properly initialised to nnodes+1 elements
 
    \param graph input graph
-   \param[out] array of degrees
+   \param[out] degree array of degrees
  */
 void NetA_degree_centrality(dglGraph_s * graph, double *degree)
 {

Modified: grass/trunk/lib/vector/neta/flow.c
===================================================================
--- grass/trunk/lib/vector/neta/flow.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/neta/flow.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -157,6 +157,7 @@
    \param graph input graph
    \param source_list list of sources
    \param sink_list list of sinks
+   \param flow
    \param[out] cut list of edges (cut)
 
    \return number of edges
@@ -250,7 +251,7 @@
 
    \param in from graph
    \param out to graph
-   \param node_cost list of node costs
+   \param node_costs list of node costs
 
    \return number of undirected edges in the graph
    \return -1 on failure

Modified: grass/trunk/lib/vector/vedit/cats.c
===================================================================
--- grass/trunk/lib/vector/vedit/cats.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/vedit/cats.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -22,7 +22,7 @@
   \param List list of selected primitives
   \param layer layer number
   \param del action (non-zero for delete otherwise add)
-  \param cats_list list of category numbers
+  \param Clist list of category numbers
   
   \return number of modified primitives
   \return -1 on error

Modified: grass/trunk/lib/vector/vedit/distance.c
===================================================================
--- grass/trunk/lib/vector/vedit/distance.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/vector/vedit/distance.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -20,7 +20,8 @@
   
   \param Points1 first line geometry
   \param Points2 second line geometry
-  \param[out] index of minimal distance
+  \param with_z WITH_Z for 3D data
+  \param[out] mindistidx index of minimal distance
   
   \return minimal distance betwen two lines (their nodes)
 */



More information about the grass-commit mailing list
--- grass/trunk/lib/raster/color_hist.c	2012-09-08 19:32:55 UTC (rev 53132)
+++ grass/trunk/lib/raster/color_hist.c	2012-09-08 19:34:59 UTC (rev 53133)
@@ -27,7 +27,7 @@
  * Color range is 0-255.
  *
  * \param colors pointer to Colors structure which holds color info
  * \param stalf pointer to Cell_stats structure which holds cell stats info
  */
 void Rast_make_histogram_eq_colors(struct Colors *colors,
 				   struct Cell_stats *statf)
@@ -94,7 +94,7 @@
    cell stats structure info. Color range is 0-255.
 
    \param colors pointer to Colors structure which holds color info
-   \param stalf pointer to Cell_stats structure which holds cell stats info
+   \param statf pointer to Cell_stats structure which holds cell stats info
    \param min minimum value
    \param max maximum value
  */
@@ -27,7 +27,7 @@
  *
  * \param colors pointer to Colors structure which holds color info
- * \param stalf pointer to Cell_stats structure which holds cell stats info
+ * \param statf pointer to Cell_stats structure which holds cell stats info
  */
 void Rast_make_histogram_eq_colors(struct Colors *colors,

Modified: grass/trunk/lib/raster/color_rule.c
===================================================================